@@ -16,7 +16,7 @@ pub struct OpalKellyDownload32FIFOTest {
 impl Logic for OpalKellyDownload32FIFOTest {
     #[hdl_gen]
     fn update(&mut self) {
-        self.hi.link(&mut self.ok_host.hi);
+        OpalKellyHostInterface::link(&mut self.hi, &mut self.ok_host.hi);
         self.dl.clock.next = self.ok_host.ti_clk.val();
         self.counter.clk.next = self.ok_host.ti_clk.val();
         self.dl.ok1.next = self.ok_host.ok1.val();
@@ -71,7 +71,7 @@ pub struct OpalKellyDownloadFIFOTest {
 impl Logic for OpalKellyDownloadFIFOTest {
     #[hdl_gen]
     fn update(&mut self) {
-        self.hi.link(&mut self.ok_host.hi);
+        OpalKellyHostInterface::link(&mut self.hi, &mut self.ok_host.hi);
         self.dl.ok1.next = self.ok_host.ok1.val();
         self.ok_host.ok2.next = self.dl.ok2.val();
         self.dl.clock.next = self.ok_host.ti_clk.val();
